==> cramr_ui_lib-0.0.3.tar.gz: lib/routes/verb_indicative_study_form_state.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_route.dart';
import 'package:cramr_ui_lib/theme/custom_theme.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// The state of the form that allows you to study the indicative of a [Verb]
class VerbIndicativeStudyFormState extends State<VerbIndicativeStudyRoute> {
  List<bool> _coverStatus = [true, true, true, true, true, true];

  Widget _listView(BuildContext context) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return ListView.builder(
          key: Key('study_scroll_${testModel.verb.infinitive}'),
          itemCount: 6,
          itemBuilder: (BuildContext context, int index) {
            return Padding(
              key: UniqueKey(),
              padding: const EdgeInsets.fromLTRB(20, 0, 20, 0),
              child: Card(
                key: UniqueKey(),
                clipBehavior: Clip.antiAlias,
                child: ListTile(
                  key: UniqueKey(),
                  visualDensity: VisualDensity.comfortable,
                  contentPadding: EdgeInsets.fromLTRB(15, 2, 30, 2),
                  dense: true,
                  leading: _pronounCell(context, index),
                  title: _verbCard(context, index),
                ),
                elevation: 5.0,
              ),
            );
          });
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: "Verbomatique",
      theme: CustomTheme.lightTheme,
      home: SafeArea(
        key: UniqueKey(),
        child: Scaffold(
          appBar: AppBar(
            title: _titleCell(context),
            actions: [
              _homeIcon(context),
            ],
          ),
          body: Container(
              key: UniqueKey(),
              child: _centerWidget(context)),
          floatingActionButton: FloatingActionButton(
            key: Key('forward_button'),
            onPressed: () {
              Navigator.pushNamed(context, '/verbIndicativeTestRoute');
            },
            child: Icon(Icons.arrow_forward),
          ),
        ),
      ),
    );
  }

  IconButton _homeIcon(BuildContext context) {
    return IconButton(
        key: Key('home_button'),
        onPressed: () {
          Navigator.restorablePopAndPushNamed(context, '/verbSelectionRoute');
        },
        icon: Icon(Icons.home));
  }

  Widget _titleCell(BuildContext context) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return Text(
        "Vervoeging ${testModel.verb.infinitive}",
        key: Key("Vervoeging ${testModel.verb.infinitive}"),
      );
    });
  }

  Widget _centerWidget(BuildContext context) {
    return Center(
      key: UniqueKey(),
      child: _listView(context),
    );
  }



  void _toggleCover(int person) {
    _coverStatus[person] = !_coverStatus[person];
    setState(() {});
  }

  String _adaptedPronoun(String isoLang, String pronoun, String expected) {
    //TODO refactor with Strategy or the likes
    if ("fr" == isoLang) {
      if ("je" == pronoun &&
          (expected.substring(0, 1) == 'a' ||
              expected.substring(0, 1) == 'e' ||
              expected.substring(0, 1) == 'i' ||
              expected.substring(0, 1) == 'o' ||
              expected.substring(0, 1) == 'u')) {
        return "j\'";
      }
    }
    return pronoun;
  }



  Widget _pronounCell(BuildContext context, int person) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return SizedBox(
        key: UniqueKey(),
        height: 40,
        width: 85,
        child: Container(
          key: Key(testModel.pronouns[person]),
          alignment: Alignment.center,
          child: Text(
            "${_adaptedPronoun(testModel.targetLanguageIso,
                testModel.pronouns[person],
                testModel.verb.indicative[person])}",
            style: TextStyle(
              color: Colors.blue,
              fontSize: 25,
            ),
            textAlign: TextAlign.center,
          ),
        ),
      );
    });
  }

  Widget _verbCard(BuildContext context, int person) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child)
    {
      return InkWell(
        key: Key('cover_${testModel.verb.infinitive}_${person}'),
        child: _coverStatus[person]
            ? Card(
          key: UniqueKey(),
          child: SizedBox(
            height: 40,
            width: 150,
            child: Container(
              key: UniqueKey(),
              color: Colors.green[400],
            ),
          ),
          elevation: 15.0,
          shadowColor: Colors.green[600],
        )
            : Card(
          key: UniqueKey(),
          child: SizedBox(
            height: 40,
            width: 150,
            child: Container(
              key: UniqueKey(),
              alignment: Alignment.center,
              child: Text("${testModel.verb.indicative[person]}",
                  key: UniqueKey(),
                  style: TextStyle(
                    color: Colors.green,
                    fontSize: 25,
                  )),
            ),
          ),
          elevation: 10.0,
        ),
        onTap: () => {_toggleCover(person)},
      );
    });
  }
}

==> cramr_ui_lib-0.0.5.tar.gz: lib/routes/verb_indicative_study_form_state.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_form_appbar.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_route.dart';
import 'package:cramr_ui_lib/theme/custom_theme.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// The state of the form that allows you to study the indicative of a [Verb]
class VerbIndicativeStudyFormState extends State<VerbIndicativeStudyRoute> {
  List<bool> _coverStatus = [true, true, true, true, true, true];

  Widget _listView(BuildContext context) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return ListView.builder(
          key: Key('study_scroll_${testModel.verb.infinitive}'),
          itemCount: 6,
          itemBuilder: (BuildContext context, int index) {
            return Padding(
              key: UniqueKey(),
              padding: const EdgeInsets.fromLTRB(20, 0, 20, 0),
              child: Card(
                key: UniqueKey(),
                clipBehavior: Clip.antiAlias,
                child: ListTile(
                  key: UniqueKey(),
                  visualDensity: VisualDensity.comfortable,
                  contentPadding: EdgeInsets.fromLTRB(15, 2, 30, 2),
                  dense: true,
                  leading: _pronounCell(context, index),
                  title: _verbCard(context, index),
                ),
                elevation: 5.0,
              ),
            );
          });
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: "Verbomatique",
      theme: CustomTheme.lightTheme,
      home: SafeArea(
        key: UniqueKey(),
        child: Scaffold(
          appBar: VerbIndicativeStudyFormAppbar().asWidget(context),
          body: Container(key: UniqueKey(), child: _centerWidget(context)),
          floatingActionButton: FloatingActionButton(
            key: Key('forward_button'),
            onPressed: () {
              Navigator.pushNamed(context, '/verbIndicativeCoverModeTestRoute');
            },
            child: Icon(Icons.arrow_forward),
          ),
        ),
      ),
    );
  }

  Widget _centerWidget(BuildContext context) {
    return Center(
      key: UniqueKey(),
      child: _listView(context),
    );
  }

  void _toggleCover(int person) {
    _coverStatus[person] = !_coverStatus[person];
    setState(() {});
  }

  String _adaptedPronoun(String isoLang, String pronoun, String expected) {
    //TODO refactor with Strategy or the likes
    if ("fr" == isoLang) {
      if ("je" == pronoun &&
          (expected.substring(0, 1) == 'a' ||
              expected.substring(0, 1) == 'e' ||
              expected.substring(0, 1) == 'i' ||
              expected.substring(0, 1) == 'o' ||
              expected.substring(0, 1) == 'u')) {
        return "j\'";
      }
    }
    return pronoun;
  }

  Widget _pronounCell(BuildContext context, int person) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return SizedBox(
        key: UniqueKey(),
        height: 40,
        width: 85,
        child: Container(
          key: Key(testModel.pronouns[person]),
          alignment: Alignment.center,
          child: Text(
            "${_adaptedPronoun(testModel.targetLanguageIso, testModel.pronouns[person], testModel.verb.indicative[person])}",
            style: TextStyle(
              color: Colors.blue,
              fontSize: 25,
            ),
            textAlign: TextAlign.center,
          ),
        ),
      );
    });
  }

  Widget _verbCard(BuildContext context, int person) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return InkWell(
        key: Key('cover_${testModel.verb.infinitive}_${person}'),
        child: _coverStatus[person]
            ? Card(
                key: UniqueKey(),
                child: SizedBox(
                  height: 40,
                  width: 150,
                  child: Container(
                    key: UniqueKey(),
                    color: Colors.green[400],
                  ),
                ),
                elevation: 15.0,
                shadowColor: Colors.green[600],
              )
            : Card(
                key: UniqueKey(),
                child: SizedBox(
                  height: 40,
                  width: 150,
                  child: Container(
                    key: UniqueKey(),
                    alignment: Alignment.center,
                    child: Text("${testModel.verb.indicative[person]}",
                        key: UniqueKey(),
                        style: TextStyle(
                          color: Colors.green,
                          fontSize: 25,
                        )),
                  ),
                ),
                elevation: 10.0,
              ),
        onTap: () => {_toggleCover(person)},
      );
    });
  }
}
